@@ -2,24 +2,27 @@ from ftw.builder import Builder
 from ftw.builder import create
 from ftw.simplelayout.interfaces import ISimplelayoutDefaultSettings
 from ftw.simplelayout.testing import FTW_SIMPLELAYOUT_CONTENT_TESTING
-from ftw.simplelayout.testing import IS_PLONE_5
+from ftw.simplelayout.utils import IS_PLONE_5
 from ftw.testbrowser import browsing
 from plone import api
 from plone.app.textfield.value import RichTextValue
 from plone.namedfile.file import NamedBlobImage
+from plone.registry.interfaces import IRegistry
 from plone.uuid.interfaces import IUUID
-from Products.CMFCore.utils import getToolByName
 from StringIO import StringIO
-from unittest2 import skipUnless
-from unittest2 import TestCase
+from unittest import TestCase
 from z3c.relationfield import RelationValue
 from zope.component import getUtility
+from zope.component import queryUtility
 from zope.intid.interfaces import IIntIds
 import json
 import transaction
 
 
-@skipUnless(not IS_PLONE_5, 'requires plone < 5')
+if IS_PLONE_5:
+    from Products.CMFPlone.interfaces.controlpanel import IImagingSchema
+
+
 class TestTextBlockRendering(TestCase):
 
     layer = FTW_SIMPLELAYOUT_CONTENT_TESTING
@@ -152,9 +155,12 @@ class TestTextBlockRendering(TestCase):
         browser.login().visit(self.page,
                               view='sl-ajax-reload-block-view',
                               data=payload)
-        browser.visit(block, view='@@block_view')
+        browser.visit(self.page)
 
-        self.assertEquals(alt_text, browser.css('img').first.attrib['alt'])
+        self.assertEquals(
+            alt_text,
+            browser.css('.ftw-simplelayout-textblock img').first.attrib['alt']
+        )
 
     @browsing
     def test_image_alt_text_empty(self, browser):
@@ -196,22 +202,29 @@ class TestTextBlockRendering(TestCase):
         link_url = browser.css('a.colorboxLink').first.attrib['href']
 
         browser.open(link_url)
-        self.assertEquals(
-            'image/jpeg',
-            browser.headers['content-type']
-        )
+
+        if IS_PLONE_5:
+            self.assertEquals('image/png', browser.headers['content-type'])
+        else:
+            self.assertEquals('image/jpeg', browser.headers['content-type'])
 
     @browsing
     def test_image_overlay_when_scale_is_missing(self, browser):
-        # Get the imaging properties.
-        properties_tool = getToolByName(self.page, 'portal_properties')
-        imaging_properties = properties_tool.get('imaging_properties')
-        allowed_sizes = imaging_properties.allowed_sizes
+        if IS_PLONE_5:
+            registry = queryUtility(IRegistry)
+            sizes = registry.forInterface(IImagingSchema, prefix="plone").allowed_sizes
+
+        else:
+            ptool = api.portal.get_tool('portal_properties')
+            sizes = ptool.get('imaging_properties').allowed_sizes
 
         # Remove the colorbox scale.
-        allowed_sizes = filter(lambda x: not x.startswith('colorbox'),
-                               allowed_sizes)
-        imaging_properties.allowed_sizes = tuple(allowed_sizes)
+        allowed_sizes = filter(lambda x: not x.startswith('colorbox'), sizes)
+
+        if IS_PLONE_5:
+            registry.forInterface(IImagingSchema, prefix="plone").allowed_sizes = allowed_sizes
+        else:
+            ptool.get('imaging_properties').allowed_sizes = tuple(allowed_sizes)
         transaction.commit()
 
         block = create(Builder('sl textblock')
